/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.apache.isis.viewer.wicket.ui.pages.action;

import org.apache.isis.viewer.wicket.model.models.ActionModel;
import org.apache.isis.viewer.wicket.ui.ComponentType;
import org.apache.isis.viewer.wicket.ui.pages.PageAbstract;
import org.apache.wicket.PageParameters;
import org.apache.wicket.authorization.strategies.role.annotations.AuthorizeInstantiation;
import org.apache.wicket.markup.html.link.BookmarkablePageLink;
import org.apache.wicket.model.IModel;

/**
 * Web page representing an action invocation.
 */
@AuthorizeInstantiation("org.starobjects.wicket.roles.USER")
public class ActionPage extends PageAbstract {

    /**
     * For use with {@link Component#setResponsePage(org.apache.wicket.Page)}
     */
    public ActionPage(final ActionModel actionModel) {
        super(new PageParameters(), ComponentType.ACTION);
        addChildComponents(actionModel);
    }

    /**
     * For use through {@link BookmarkablePageLink}s.
     */
    public ActionPage(final PageParameters pageParameters) {
        super(pageParameters, ComponentType.ACTION);
        final IModel<?> model = buildModel();
        addChildComponents(model);
    }

    private IModel<?> buildModel() {
        return ActionModel.createForPersistent(getPageParameters(), getOidStringifier());
    }

}
